## Summary

Brief description of the changes.

## Changes

- ...

## Checklist

- [ ] Tests pass (`make test`)
- [ ] Linter passes (`make check`)
- [ ] Documentation updated (if applicable)
- [ ] No secrets or API keys included
